@@ -3,7 +3,7 @@
 __all__ = (
     "Formatter", "use_expand_filter",
     "BasicFormatter", "PkgcoreFormatter", "CountingFormatter",
-    "PortageFormatter", "PortageVerboseFormatter", "PaludisFormatter",
+    "PortageFormatter", "PortageVerboseFormatter",
 )
 
 import operator
@@ -346,8 +346,13 @@ class PortageFormatter(CountingFormatter):
 
         # output USE_EXPAND flags
         for expand in sorted(self.use_expand - self.use_expand_hidden):
-            flaglists = [d.get(expand, ()) for d in usedicts]
-            self.format_use(expand, *flaglists)
+            try:
+                sorter = op.pkg.repo.use_expand_sorter(expand)
+            except AttributeError:
+                # TODO: hack for unit tests using fake repo objs
+                sorter = lambda k: k
+            flaglists = [sorted(d.get(expand, ()), key=sorter) for d in usedicts]
+            self.format_use(expand, *flaglists, sorter=sorter)
 
         # output download size
         if self.verbosity > 0:
@@ -370,7 +375,7 @@ class PortageFormatter(CountingFormatter):
         out.write('\n')
         out.autoline = origautoline
 
-    def format_use(self, attr, pkg_iuse, pkg_use, old_pkg_iuse=None, old_pkg_use=None):
+    def format_use(self, attr, pkg_iuse, pkg_use, old_pkg_iuse=None, old_pkg_use=None, sorter=lambda k: k):
         """Write the current selection from a set of flags to a formatter.
 
         :type attr: string
@@ -403,7 +408,7 @@ class PortageFormatter(CountingFormatter):
             old_disabled = set(old_pkg_iuse) - set(old_pkg_use)
             removed = set(old_pkg_iuse) - set(pkg_iuse)
 
-            for flag in sorted(enabled):
+            for flag in sorted(enabled, key=sorter):
                 expanded_flag = '_'.join((attr.lower(), flag)) if attr != 'use' else flag
                 if flag in old_enabled:
                     # unchanged
@@ -425,7 +430,7 @@ class PortageFormatter(CountingFormatter):
                     else:
                         flags.extend((yellow, bold, flag, reset, '%*', ' '))
 
-            for flag in sorted(disabled):
+            for flag in sorted(disabled, key=sorter):
                 expanded_flag = '_'.join((attr.lower(), flag)) if attr != 'use' else flag
                 if flag in old_disabled:
                     # unchanged
@@ -448,7 +453,7 @@ class PortageFormatter(CountingFormatter):
                         flags.extend((yellow, bold, '-', flag, reset, '%', ' '))
 
             if self.verbosity > 0:
-                for flag in sorted(removed):
+                for flag in sorted(removed, key=sorter):
                     if flag in old_enabled:
                         flags.extend(('(', yellow, bold, '-', flag, reset, '%*)', ' '))
                     else:
@@ -456,13 +461,13 @@ class PortageFormatter(CountingFormatter):
 
         # new pkg install
         else:
-            for flag in sorted(enabled):
+            for flag in sorted(enabled, key=sorter):
                 expanded_flag = '_'.join((attr.lower(), flag)) if attr != 'use' else flag
                 if expanded_flag in self.pkg_forced_use:
                     flags.extend(('(', red, bold, flag, reset, ')', ' '))
                 else:
                     flags.extend((red, bold, flag, reset, ' '))
-            for flag in sorted(disabled):
+            for flag in sorted(disabled, key=sorter):
                 expanded_flag = '_'.join((attr.lower(), flag)) if attr != 'use' else flag
                 if expanded_flag in self.pkg_disabled_use:
                     flags.extend(('(', blue, bold, '-', flag, reset, ')', ' '))
@@ -500,56 +505,3 @@ class PortageFormatter(CountingFormatter):
 
 class PortageVerboseFormatter(VerboseFormatter, PortageFormatter):
     """Formatter designed to resemble portage output in verbose mode."""
-
-
-class PaludisFormatter(CountingFormatter):
-    """Formatter designed to resemble paludis output."""
-
-    def format(self, op):
-        out = self.out
-        origautoline = out.autoline
-        out.autoline = False
-
-        out.write('* ')
-        out.write(out.fg('blue'), op.pkg.key)
-        out.write(f"-{op.pkg.fullver}")
-        out.write(f"::{op.pkg.repo.repo_id} ")
-        out.write(out.fg('blue'), f"{{:{op.pkg.slot}}} ")
-        op_type = op.desc
-        if op.desc == 'add':
-            suffix = 'N'
-            if op.pkg.slot != '0':
-                op_type = 'slotted_add'
-                suffix = 'S'
-            out.write(out.fg('yellow'), f"[{suffix}]")
-        elif op.desc == 'replace':
-            if op.pkg != op.old_pkg:
-                if op.pkg > op.old_pkg:
-                    op_type = 'upgrade'
-                else:
-                    op_type = 'downgrade'
-                out.write(
-                    out.fg('yellow'),
-                    f"[{op_type[0].upper()} {op.old_pkg.fullver}]")
-            else:
-                out.write(out.fg('yellow'), "[R]")
-        else:
-            # shouldn't reach here
-            logger.warning("unknown op type encountered: desc(%r), %r", op.desc, op)
-        self.visit_op(op_type)
-
-        red = out.fg('red')
-        green = out.fg('green')
-        flags = []
-        use = set(op.pkg.use)
-        for flag in sorted(op.pkg.iuse_stripped):
-            if flag in use:
-                flags.extend((green, flag, ' '))
-            else:
-                flags.extend((red, '-', flag, ' '))
-        if flags:
-            out.write(' ')
-            # Throw away the final space.
-            out.write(*flags[:-1])
-        out.write('\n')
-        out.autoline = origautoline
