@@ -1,5 +1,3 @@
-from snakeoil.test import TestCase
-
 from pkgcore.config import basics
 from pkgcore.config.hint import ConfigHint
 from pkgcore.scripts import pclonecache
@@ -14,7 +12,7 @@ class Cache:
         self.readonly = self.frozen = readonly
 
 
-class CommandlineTest(TestCase, ArgParseMixin):
+class TestCommandline(ArgParseMixin):
 
     _argparser = pclonecache.argparser
 
