@@ -1,14 +1,13 @@
 from pkgcore import plugins
 from pkgcore.scripts import pplugincache
 from pkgcore.test.scripts.helpers import ArgParseMixin
-from snakeoil.test import TestCase
 
 
-class CommandlineTest(TestCase, ArgParseMixin):
+class TestCommandline(ArgParseMixin):
 
     _argparser = pplugincache.argparser
 
     has_config = False
 
     def test_parser(self):
-        self.assertEqual([plugins], self.parse().packages)
+        assert self.parse().packages == [plugins]
